@@ -2,14 +2,20 @@ package com.fasterxml.jackson.dataformat.xml;
 
 import com.fasterxml.jackson.databind.AnnotationIntrospector;
 import com.fasterxml.jackson.databind.module.SimpleModule;
+
 import com.fasterxml.jackson.dataformat.xml.deser.FromXmlParser;
 import com.fasterxml.jackson.dataformat.xml.deser.XmlBeanDeserializerModifier;
-import com.fasterxml.jackson.dataformat.xml.deser.XmlStringDeserializer;
 import com.fasterxml.jackson.dataformat.xml.ser.XmlBeanSerializerModifier;
 
 /**
  * Module that implements most functionality needed to support producing and
- * consuming XML instead of JSON.
+ * consuming XML instead of JSON, used by {@link XmlMapper} for registering
+ * handlers for XML-specific processing.
+ *<p>
+ * NOTE: please do NOT register this directly on {@link XmlMapper}: mapper
+ * registers an instance (either one explicitly given in constructor, or, if none,
+ * one it configures) and attempts to re-register is unlikely to work as
+ * you'd expect.
  */
 public class JacksonXmlModule
     extends SimpleModule
@@ -49,9 +55,6 @@ public class JacksonXmlModule
     public JacksonXmlModule()
     {
         super("JacksonXmlModule", PackageVersion.VERSION);
-        XmlStringDeserializer deser = new XmlStringDeserializer();
-        addDeserializer(String.class, deser);
-        addDeserializer(CharSequence.class, deser);
     }
 
     @SuppressWarnings("deprecation")
