@@ -7,15 +7,16 @@ import java.lang.annotation.Target;
 
 /**
  * Adding this annotation will result in value of the property to be serialized
- * within a CData tag.  Only use on String properties and String collections.
+ * within an xml {@code CDATA} section.  Only use on String properties and String collections.
  */
-@Target({ElementType.FIELD, ElementType.METHOD, ElementType.PARAMETER })
+@Target({ElementType.ANNOTATION_TYPE, ElementType.FIELD, ElementType.METHOD, ElementType.PARAMETER })
 @Retention(RetentionPolicy.RUNTIME)
 public @interface JacksonXmlCData
 {
     /**
-     * Whether the property text should always be within a CData block
-     * when serialized.
+     * Whether the property text should always be within a CDATA section
+     * when serialized. Has no meaning for deserialization; content may come from
+     * any legal character data section (CDATA or regular text segment).
      */
     public boolean value() default true;
 }
