@@ -1,25 +1,26 @@
 package com.fasterxml.jackson.dataformat.xml.jaxb;
 
+import com.fasterxml.jackson.databind.cfg.MapperConfig;
 import com.fasterxml.jackson.databind.introspect.*;
 import com.fasterxml.jackson.databind.type.TypeFactory;
 import com.fasterxml.jackson.dataformat.xml.XmlAnnotationIntrospector;
-import com.fasterxml.jackson.module.jaxb.JaxbAnnotationIntrospector;
 
 /**
  * Alternative {@link com.fasterxml.jackson.databind.AnnotationIntrospector}
  * implementation that
- * builds on {@link JaxbAnnotationIntrospector}.
+ * that USED TO build on {@code JaxbAnnotationIntrospector} from
+ * {@code jackson-module-jaxb-annotatins} package.
+ * But as of Jackson 2.13, SHOULD NOT BE USED as it DOES NOT WORK.
+ * Removal was necessary because XML format package does not (and can not)
+ * depend on JAXB annotations.
+ * Class WILL BE REMOVED from Jackson 2.14 or later on.
  *<p>
- * NOTE: since version 2.4, it may NOT be necessary to use this class;
- * instead, plain {@link JaxbAnnotationIntrospector} should fully work.
- * With previous versions some aspects were not fully working and this
- * class was necessary.
  *
- * @deprecated Since 2.12 (as per above notes)
+ * @deprecated Since 2.12 (as per above notes): broken since 2.13
  */
 @Deprecated
 public class XmlJaxbAnnotationIntrospector
-    extends JaxbAnnotationIntrospector
+    extends NopAnnotationIntrospector
     implements XmlAnnotationIntrospector
 {
     private static final long serialVersionUID = 1L; // since 2.7
@@ -30,7 +31,7 @@ public class XmlJaxbAnnotationIntrospector
     }
 
     public XmlJaxbAnnotationIntrospector(TypeFactory typeFactory) {
-        super(typeFactory);
+        super();
     }
 
     /*
@@ -40,28 +41,22 @@ public class XmlJaxbAnnotationIntrospector
      */
 
     @Override
-    public String findNamespace(Annotated ann) {
-        return super.findNamespace(ann);
-    }
-
-    @Override
-    public Boolean isOutputAsAttribute(Annotated ann) {
-        return super.isOutputAsAttribute(ann);
-    }
-
-    @Override
-    public Boolean isOutputAsText(Annotated ann) {
-        return super.isOutputAsText(ann);
-    }
-
-    @Override
-    public Boolean isOutputAsCData(Annotated ann) {
-        //There is no CData annotation in JAXB
+    public String findNamespace(MapperConfig<?> config, Annotated ann) {
         return null;
     }
 
     @Override
-    public void setDefaultUseWrapper(boolean b) {
-        // nothing to do with JAXB
+    public Boolean isOutputAsAttribute(MapperConfig<?> config, Annotated ann) {
+        return null;
+    }
+
+    @Override
+    public Boolean isOutputAsText(MapperConfig<?> config, Annotated ann) {
+        return null;
+    }
+
+    @Override
+    public Boolean isOutputAsCData(MapperConfig<?> config, Annotated ann) {
+        return null;
     }
 }
