@@ -9,6 +9,12 @@ import junit.framework.TestCase;
 import com.fasterxml.jackson.annotation.JsonPropertyOrder;
 
 import com.fasterxml.jackson.core.*;
+
+import com.fasterxml.jackson.databind.AnnotationIntrospector;
+import com.fasterxml.jackson.databind.type.TypeFactory;
+
+import com.fasterxml.jackson.module.jakarta.xmlbind.JakartaXmlBindAnnotationIntrospector;
+
 import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
 
 public abstract class XmlTestBase
@@ -231,6 +237,10 @@ public abstract class XmlTestBase
         return new XmlMapper(module);
     }
 
+    protected AnnotationIntrospector jakartaXMLBindAnnotationIntrospector() {
+        return new JakartaXmlBindAnnotationIntrospector(TypeFactory.defaultInstance());
+    }
+
     /*
     /**********************************************************
     /* Additional assertion methods
@@ -334,13 +344,36 @@ public abstract class XmlTestBase
         return sb.toString();
     }
 
+    protected byte[] readResource(String ref)
+    {
+       ByteArrayOutputStream bytes = new ByteArrayOutputStream();
+       final byte[] buf = new byte[4000];
+
+       InputStream in = getClass().getResourceAsStream(ref);
+       if (in != null) {
+           try {
+               int len;
+               while ((len = in.read(buf)) > 0) {
+                   bytes.write(buf, 0, len);
+               }
+               in.close();
+           } catch (IOException e) {
+               throw new RuntimeException("Failed to read resource '"+ref+"': "+e);
+           }
+       }
+       if (bytes.size() == 0) {
+           throw new IllegalArgumentException("Failed to read resource '"+ref+"': empty resource?");
+       }
+       return bytes.toByteArray();
+    }
+    
     public String jaxbSerialized(Object ob, Class<?>... classes) throws Exception
     {
         StringWriter sw = new StringWriter();
         if (classes.length == 0) {
-            javax.xml.bind.JAXB.marshal(ob, sw);
+            jakarta.xml.bind.JAXB.marshal(ob, sw);
         } else {
-            javax.xml.bind.JAXBContext.newInstance(classes).createMarshaller().marshal(ob, sw);
+            jakarta.xml.bind.JAXBContext.newInstance(classes).createMarshaller().marshal(ob, sw);
         }
         sw.close();
         return sw.toString();
