@@ -3,16 +3,16 @@ package com.fasterxml.jackson.dataformat.xml.jaxb;
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.xml.bind.annotation.*;
+import jakarta.xml.bind.annotation.*;
 
 import com.fasterxml.jackson.annotation.*;
+
 import com.fasterxml.jackson.databind.AnnotationIntrospector;
 import com.fasterxml.jackson.databind.introspect.JacksonAnnotationIntrospector;
-import com.fasterxml.jackson.databind.type.TypeFactory;
+
 import com.fasterxml.jackson.dataformat.xml.XmlAnnotationIntrospector;
 import com.fasterxml.jackson.dataformat.xml.XmlMapper;
 import com.fasterxml.jackson.dataformat.xml.XmlTestBase;
-import com.fasterxml.jackson.module.jaxb.JaxbAnnotationIntrospector;
 
 public class JAXBObjectId170Test extends XmlTestBase
 {
@@ -117,7 +117,7 @@ public class JAXBObjectId170Test extends XmlTestBase
 "</company>\n"
                 ;
 
-        JaxbAnnotationIntrospector xmlIntr = new JaxbAnnotationIntrospector(TypeFactory.defaultInstance());
+        AnnotationIntrospector xmlIntr = jakartaXMLBindAnnotationIntrospector();
         AnnotationIntrospector intr = XmlAnnotationIntrospector.Pair.instance
                 (xmlIntr, new JacksonAnnotationIntrospector());
         XmlMapper mapper = mapperBuilder()
