@@ -2,16 +2,14 @@ package com.fasterxml.jackson.dataformat.xml.jaxb;
 
 import java.io.IOException;
 
-import javax.xml.bind.annotation.*;
+import jakarta.xml.bind.annotation.*;
 
 import com.fasterxml.jackson.databind.AnnotationIntrospector;
 import com.fasterxml.jackson.databind.introspect.JacksonAnnotationIntrospector;
-import com.fasterxml.jackson.databind.type.TypeFactory;
 
 import com.fasterxml.jackson.dataformat.xml.XmlAnnotationIntrospector;
 import com.fasterxml.jackson.dataformat.xml.XmlMapper;
 import com.fasterxml.jackson.dataformat.xml.XmlTestBase;
-import com.fasterxml.jackson.module.jaxb.JaxbAnnotationIntrospector;
 
 /**
  * Although XML-backed data binding does not rely (or directly build) on JAXB
@@ -38,13 +36,13 @@ public class WithJAXBAnnotationsTest extends XmlTestBase
         public String attr = "3";
     }
 
-    @javax.xml.bind.annotation.XmlRootElement(name="Simple")
+    @jakarta.xml.bind.annotation.XmlRootElement(name="Simple")
     static class WithXmlValue
     {
-        @javax.xml.bind.annotation.XmlAttribute
+        @jakarta.xml.bind.annotation.XmlAttribute
         public int a = 13;
 
-        @javax.xml.bind.annotation.XmlValue
+        @jakarta.xml.bind.annotation.XmlValue
         public String text = "something";
     }
 
@@ -98,7 +96,7 @@ public class WithJAXBAnnotationsTest extends XmlTestBase
         _nonJaxbMapper = new XmlMapper();
         // Use JAXB-then-Jackson annotation introspector
         AnnotationIntrospector intr = XmlAnnotationIntrospector.Pair.instance
-            (new JaxbAnnotationIntrospector(TypeFactory.defaultInstance()), new JacksonAnnotationIntrospector());
+                (jakartaXMLBindAnnotationIntrospector(), new JacksonAnnotationIntrospector());
         _jaxbMapper.setAnnotationIntrospector(intr);
     }
 
